/*
 * ks0108_Panel.h - User specific configuration for Arduino GLCD library
 *
 * Use this file to set LCD panel parameters
 * This version is for a standard ks0108 display
 * This file uses a board specific pin assignment file based on the board selected in the IDE
 *
*/

#ifndef GLCD_PANEL_CONFIG_H
#define GLCD_PANEL_CONFIG_H

//#define GLCD_READ_CACHE       // Turns on code that uses a frame buffer for a read cache

/*
 * define name for panel configuration
 */
#define glcd_PanelConfigName "st7565_dmg12864i"

/*********************************************************/
/*  Configuration for LCD panel specific configuration   */
/*********************************************************/
#define DISPLAY_WIDTH 128
#define DISPLAY_HEIGHT 64

// panel controller chips
#define CHIP_WIDTH     64  // pixels per chip
#define CHIP_HEIGHT    64  // pixels per chip

/*
 * the following is the calculation of the number of chips - do not change
 */
#define glcd_CHIP_COUNT 1 // (((DISPLAY_WIDTH + CHIP_WIDTH - 1)  / CHIP_WIDTH) * ((DISPLAY_HEIGHT + CHIP_HEIGHT -1) / CHIP_HEIGHT))

/*********************************************************/
/*  Chip Select Configuration                            */
/*********************************************************/

/*
 * Change the following define to match the number of Chip Select pins for this panel
 * Most panels use two pins for chip select,
 * but check your datasheet to see if a different number is required
 */
#define NBR_CHIP_SELECT_PINS   0 // the number of chip select pins required for this panel 



/*********************************************************/
/*  End of Chip Select Configuration                     */
/*********************************************************/

/*
 * The following defines are for panel specific low level timing.
 *
 * See your data sheet for the exact timing and waveforms.
 * All defines below are in nanoseconds.
 */

#define GLCD_tDDR  320    /* Data Delay time (E high to valid read data)        */
#define GLCD_tAS   140    /* Address setup time (ctrl line changes to E HIGH   */
#define GLCD_tDSW  200    /* Data setup time (data lines setup to dropping E)   */
#define GLCD_tWH   450    /* E hi level width (minimum E hi pulse width)        */
#define GLCD_tWL   450    /* E lo level width (minimum E lo pulse width)        */


 /*
  * The code below selects a configuration file for pin assignment based on the board selected in the IDE 
  * These configurations are compatible with wiring used in earlier versions of the library
  * WARNING: When adding new board types it is not as simple as just editing these lines.
  * There is also a dependency on the file glcd/include/arduino.h which does the arduino pin mappings
  */
 
#if defined(__AVR_ATmega1280__) || defined(__AVR_ATmega2560__)
#include "config/ks0108_Mega.h"      // config for mega 1280/2560 board
#elif defined(__AVR_ATmega644P__)  || defined(__AVR_ATmega644__)           
#include "config/ks0108_Sanguino.h"  // config for Sanguino or other ATmega644/p board
#elif defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB1286__) || defined(__AVR_ATmega32U4__)// Teensy
#include "config/ks0108_Teensy.h"    // config for Teensy and Teensy++  
#else
#   if defined( __AVR__ )
#       include "config/st7565_DMG12864I_Arduino.h"   // config file for standard Arduino using documented wiring 
#   else
#       include "config/st7565_DMG12864I_Maple.h"
#   endif
#endif

#include "device/st7565_DMG12864I_Device.h"
#endif //GLCD_PANEL_CONFIG_H
