/*
  st7565.h - Maple library support for graphic LCDs 

 vi:ts=4

*/

#ifndef ST7565_DEVICE_H
#define ST7565_DEVICE_H

#include "wirish.h"

/*
 * define name for Device
 */
#define glcd_DeviceName "st7565_ad_12864_spi"
#define ST7565_AD_12864_SPI







/*
 * Sanity check ST7565 config pins
 *
 *	Help the user detect pin configuration errors by
 *	detecting when defines are missing or are incorrect.
 *
 *	Check for existence/non-existence of:

 */


/*
 * LCD commands -------------------------------------------------------------
 */
#define LCD_ON				0xAF	// Turn on LCD panel
#define LCD_OFF            	0xAE	// Turn off LCD panel
#define LCD_DISP_START		0x40	// Initial Disply Line

#define LCD_SET_PAGE		0xB0
#define LCD_SET_ADDLO     	0x00	// set column (Segment) address lo nibble
#define LCD_SET_ADDHI     	0x10	// set column (Segment) address hi nibble

//#define LCD_ADC_RIGHTWWARD	0xA0		
//#define LCD_ADC_LEFTWARD	0xA1		
//#define LCD_REVERSELCD		0xa7	// white dots on black background.
//#define LCD_NORMALLCD		0xa6	// black dots on white backbround

//#define LCD_RESET			0xE2	// Reset command not signal reset

/*
 * Status register bits/flags -----------------------------------------------
 */

//#define LCD_BUSY_FLAG		0x80 
//#define LCD_BUSY_BIT		7

/*
 * Define primitives used by glcd_Device.cpp --------------------------------
 */


/*
 * The current ST7565 doesn't use chip selects
 * As it is currently only set up for a single chip
 */
#define glcd_DevSelectChip(chip) //NA

/*
 * ST7565 currently doesn't use/need a chip # to strobe EN
 * as there is only a single EN line, so ignore the chip parameter.
 */
#define glcd_DevENstrobeHi(chip) //NA
#define glcd_DevENstrobeLo(chip) //NA


/*
 * Convert X coordinate to chip values
 */
#define glcd_DevXYval2Chip(x,y)		(0)	// no multi chip support yet.

#define glcd_DevXval2ChipCol(x)	    (x)	// no multi chip support yet

/*
 * Convert from chip column value to hi/lo address value
 * for LCD commands.
 */

#define glcd_DevCol2addrlo(x)		(x & 0xf)	// lo nibble
#define glcd_DevCol2addrhi(x)		((x & 0xf0)>>4)	// hi nibble


/* Define  HardwareSPI object */
#define _SPI_OBJ spi_obj
#define DEFINE_SPI_OBJECT HardwareSPI _SPI_OBJ( SPI_NUMBER )
extern HardwareSPI _SPI_OBJ;

/* Initialize SPI */
#define Spi_init() { \
	_SPI_OBJ.begin( SPI_CLOCK_VALUE, MSBFIRST, 0); \
	lcdPinMode(glcdCS1,OUTPUT); \
	mSpi_Lcd_CS_disable(); \
}

#define Lcd_Cmd(c)    WriteCommand(c, 0)
#define glcd_DeviceInit(c) \
({ \
 uint8_t status;									\
	do{												\
	Spi_init(); \
	Lcd_Cmd(0xaf); /* LCD On */ \
	Lcd_Cmd(0x2f); /* Set power control mode */ \
\
	Lcd_Cmd(0x81); /* Set electronic volume mode */ \
	Lcd_Cmd(0x0a); /* *[0a-0f]set volume data 0x0000~0x003f */ \
\
	Lcd_Cmd(0x24); /* *[0x24]Set V5 internal voltage adjustment resistor */ \
	Lcd_Cmd(0xa3); /* ***[0xa3 only]Set LCD bias */ \
\
	Lcd_Cmd(0xc8); /* Com scan direction set, reverse */ \
	Lcd_Cmd(0xa0); /* normal, Select segment direction, */ \
	Lcd_Cmd(0xa4); /* normal, Set all point ON/OFF command  */ \
	Lcd_Cmd(0xa6); /* normal, Set normal/reverse display command */ \
\
	Lcd_Cmd(0xad); /* normal, sleep mode ,Close static indicator */ \
	Lcd_Cmd(0x00); /* Command data */ \
	Lcd_Cmd(0x40 +0 ); /* Set start common RAM */ \
	}while(0);										\
	status = GLCD_ENOERR; \
	status; /* return value of macro */				\
})

//	Lcd_Cmd(LCD_ON);			// display on
//	Lcd_Cmd(LCD_DISP_START);	// display start line = 0

#endif //GLCD_PANEL_DEVICE_H
